==> react-static-plugin-typescript-2.1.0.tgz: package/README.md <==
react-static-plugin-typescript
======
A plugin for [React Static](https://react-static.js.org/) that allows you to use [TypeScript](https://www.typescriptlang.org/).

## Installation

```bash
npm install react-static-plugin-typescript @types/react --save-dev
```

## Usage

There are three steps to complete before being able to use this plugin.

First, add the plugin to your `static.config.js`:

```javascript
export default {
  plugins: [
    'react-static-plugin-typescript'
  ]
};
```

Then add a `tsconfig.json`, e.g. this one:

```json
{
  "compilerOptions": {
    "target": "es2015",
    "module": "esnext",
    "lib": ["es2015", "dom"],
    "moduleResolution": "node",
    "skipLibCheck": true,
    "allowJs": true,
    "jsx": "preserve",
    "sourceMap": true,
    "removeComments": false,
    "strict": true,
    "esModuleInterop": true,
  },
}
```

Finally, rename a file from `.js` to `.tsx`. You can then start using TypeScript!

## Options

Options [can be passed by using an array](https://github.com/nozzle/react-static/tree/master/docs/plugins#plugin-options), e.g.:

```javascript
// In static.config.js:
export default {
  plugins: [
    [ 'react-static-plugin-typescript', { typeCheck: true } ]
  ]
};
```

### `typeCheck: boolean`

Default value: `false`

Enable type checking for your application during compilation. This is currently off by default (i.e. your TypeScript files will get loaded, but you won't get warnings about type errors unless you set that up separately, e.g. in your editor). Turning this on means that your application will fail to run locally as long as there are type errors.

This option will be turned on by default in a future major release.

## License

MIT © [Vincent Tunru](https://vincenttunru.com)

==> react-static-plugin-typescript-3.0.0.tgz: package/README.md <==
react-static-plugin-typescript
======
A plugin for [React Static](https://react-static.js.org/) that allows you to use [TypeScript](https://www.typescriptlang.org/).

## Installation

```bash
npm install react-static-plugin-typescript @types/react --save-dev
```

## Usage

There are three steps to complete before being able to use this plugin.

First, add the plugin to your `static.config.js`:

```javascript
export default {
  plugins: [
    'react-static-plugin-typescript'
  ]
};
```

Then add a `tsconfig.json`, e.g. this one:

```json
{
  "compilerOptions": {
    "target": "es2015",
    "module": "esnext",
    "lib": ["es2015", "dom"],
    "moduleResolution": "node",
    "skipLibCheck": true,
    "allowJs": true,
    "jsx": "preserve",
    "sourceMap": true,
    "removeComments": false,
    "strict": true,
    "esModuleInterop": true,
  },
}
```

Finally, rename a file from `.js` to `.tsx`. You can then start using TypeScript!

## Options

Options [can be passed by using an array](https://github.com/nozzle/react-static/tree/master/docs/plugins#plugin-options), e.g.:

```javascript
// In static.config.js:
export default {
  plugins: [
    [ 'react-static-plugin-typescript', { typeCheck: true } ]
  ]
};
```

### `typeCheck: boolean`

Default value: `true`

Enable or disable type checking for your application during compilation. When this is off, your TypeScript files will still be loaded, but you won't get warnings about type errors unless you set that up separately, e.g. in your editor, a commit hook, or in your CI server. When this is on, your application will fail to run locally when there are type errors.

## License

MIT © [Vincent Tunru](https://vincenttunru.com)
